Package: ibr
Version: 2.4-2
Date: 2026-06-01
Title: Iterative Bias Reduction
Authors@R: c(person("Pierre-Andre", "Cornillon", role = c("aut", "cre"),
                     email = "pierre-andre.cornillon@univ-rennes2.fr"),
              person("Nicolas", "Hengartner", role = "aut"),
              person("Eric", "Matzner-Lober", role = "aut"))
Depends: R (>= 2.11.1), mgcv
Imports: stats, graphics
Description: Multivariate smoothing using iterative bias reduction with kernel, thin plate splines, Duchon splines or low rank splines. 
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2026-06-02 11:50:19 UTC; pac
Author: Pierre-Andre Cornillon [aut, cre],
  Nicolas Hengartner [aut],
  Eric Matzner-Lober [aut]
Maintainer: Pierre-Andre Cornillon <pierre-andre.cornillon@univ-rennes2.fr>
Repository: CRAN
Date/Publication: 2026-06-02 12:00:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-06-02 13:46:52 UTC; unix
Archs: ibr.so.dSYM
