export(AIC.ibr,AICc,AICc.ibr,BIC.ibr,bwchoice,cvobs,departnoyau,dssmoother,dsSx,DuchonQ,DuchonS,
       forward,GCV,GCV.ibr,ibr,ibr.fit,kernelKx,kernelSx,lambdachoice,lambdachoicelr,lrsmoother,
       npregress,plot.forwardibr,plot.ibr,predict.ibr,predict.npregress,print.ibr,print.npregress,print.summary.ibr,print.summary.npregress,
       residuals.ibr,summary.ibr,summary.npregress)

importFrom(stats, BIC,delete.response, is.empty.model, model.frame,model.matrix, model.offset, model.response, na.fail,na.omit, optimize, predict, quantile, residuals, sd, terms, uniroot)
importFrom(graphics, plot,abline,image,text)
importFrom(mgcv,PredictMat,smoothCon)
S3method(plot,ibr)
S3method(predict,ibr)
S3method(print,ibr)
S3method(residuals,ibr)
S3method(summary,ibr)
S3method(print,npregress)
S3method(predict,npregress)
S3method(summary,npregress)
S3method(plot,forwardibr)
S3method(print,summary.ibr)
S3method(print,summary.npregress)
S3method(AIC,ibr)
S3method(BIC,ibr)
S3method(GCV,ibr)
S3method(AICc,ibr)
useDynLib(ibr, .registration = TRUE, .fixes = "ibr_")

